@@ -23,14 +23,15 @@ TSFPGA_MODULES = REPO_ROOT / "modules"
 TSFPGA_TCL = THIS_DIR / "vivado" / "tcl"
 TSFPGA_GENERATED = REPO_ROOT / "generated"
 
-TSFPGA_EXAMPLES = REPO_ROOT / "examples"
+TSFPGA_EXAMPLES = TSFPGA_PATH / "examples"
 TSFPGA_EXAMPLE_MODULES = TSFPGA_EXAMPLES / "modules"
-TSFPGA_EXAMPLE_MODULES_WITH_IP = TSFPGA_EXAMPLES / "modules_with_ip"
 
 ALL_TSFPGA_MODULES_FOLDERS = [
     TSFPGA_MODULES,
     TSFPGA_EXAMPLE_MODULES,
-    TSFPGA_EXAMPLE_MODULES_WITH_IP,
 ]
 
-__version__ = "8.0.1"
+# Default encoding when opening files
+DEFAULT_FILE_ENCODING = "utf-8"
+
+__version__ = "9.0.0"
