@@ -24,12 +24,12 @@ class GitSimulationSubset:
     ):
         """
         Arguments:
-            repo_root (``pathlib.Path``): Root directory where git commands will be run.
+            repo_root (`pathlib.Path`): Root directory where git commands will be run.
             reference_branch (str): What git branch to compare against, when finding what files have
                 changed. Typically "origin/master".
             vunit_proj: A vunit project with all source files and testbenches added. Will be used
                 for dependency scanning.
-            vunit_preprocessed_path (``pathlib.Path``): If location/check preprocessing is enabled
+            vunit_preprocessed_path (`pathlib.Path`): If location/check preprocessing is enabled
                 in your VUnit project, supply the path to vunit_out/preprocessed.
             modules (.ModuleList): A list of modules that are included in the VUnit project. Must be
                 supplied only if preprocessing is enabled.
