@@ -13,19 +13,21 @@ from platform import system
 from shutil import rmtree
 import subprocess
 
+from tsfpga import DEFAULT_FILE_ENCODING
+
 
 def create_file(file, contents=None):
     create_directory(file.parent, empty=False)
 
     contents = "" if contents is None else contents
-    with file.open("w") as file_handle:
+    with open(file, "w", encoding=DEFAULT_FILE_ENCODING) as file_handle:
         file_handle.write(contents)
 
     return file
 
 
 def read_file(file):
-    with file.open() as file_handle:
+    with open(file, encoding=DEFAULT_FILE_ENCODING) as file_handle:
         return file_handle.read()
 
 
@@ -44,7 +46,7 @@ def read_last_lines_of_file(file, num_lines):
     result_lines = []
     blocks_to_read = 0
 
-    with open(file) as file_handle:
+    with open(file, encoding=DEFAULT_FILE_ENCODING) as file_handle:
         while len(result_lines) < num_lines:
             # Since we do not know the line lengths, there is some guessing involved. Keep reading
             # larger and larger blocks until we have all the lines that are requested.
@@ -94,7 +96,7 @@ def file_is_in_directory(file_path, directories):
         directories (list(`pathlib.Path`)): The directories to be controlled.
 
     Returns:
-        bool: True if there is a comon path.
+        bool: True if there is a common path.
     """
     for directory in directories:
         if commonpath([str(file_path), str(directory)]) == str(directory):
@@ -102,11 +104,11 @@ def file_is_in_directory(file_path, directories):
     return False
 
 
-def run_command(cmd, cwd=None):
+def run_command(cmd, cwd=None, env=None):
     if not isinstance(cmd, list):
         raise ValueError("Must be called with a list, not a string")
 
-    subprocess.check_call(cmd, cwd=cwd)
+    subprocess.check_call(cmd, cwd=cwd, env=env)
 
 
 def load_python_module(file):
