@@ -19,7 +19,7 @@ from tsfpga.git_utils import (
     find_git_files,
     get_git_commit,
 )
-from tsfpga.system_utils import create_file, system_is_windows
+from tsfpga.system_utils import create_directory, create_file, system_is_windows
 
 
 THIS_FILE = Path(__file__)
@@ -96,17 +96,15 @@ class TestGitCommitWithLocalChanges(unittest.TestCase):
         self.repo = Repo.init(self.repo_path)
         self.actor = Actor("A name", "an@email.com")
 
-        initial_file = self.repo_path / "initial_commit_file.txt"
-        create_file(initial_file)
+        initial_file = create_file(self.repo_path / "initial_commit_file.txt")
         self.repo.index.add(str(initial_file))
         self.repo.index.commit("Initial commit", author=self.actor, committer=self.actor)
 
-        self.trash_file = self.repo_path / "local_file_for_git_test.apa"
-        create_file(self.trash_file)
-        self.repo.index.add(str(self.trash_file))
+        trash_file = create_file(self.repo_path / "local_file_for_git_test.apa")
+        self.repo.index.add(str(trash_file))
 
     def test_get_git_commit_with_local_changes(self):
-        assert get_git_commit(directory=self.repo_path).endswith(" (local changes present)")
+        assert get_git_commit(directory=self.repo_path).endswith(self._local_changes_present)
 
     def test_get_git_commit_with_env_variable_and_local_changes(self):
         if "GIT_COMMIT" in os.environ:
@@ -125,3 +123,7 @@ class TestGitCommitWithLocalChanges(unittest.TestCase):
     def test_get_git_commit_without_local_changes(self):
         self.repo.index.commit("Trash commit", author=self.actor, committer=self.actor)
         assert not get_git_commit(directory=self.repo_path).endswith(self._local_changes_present)
+
+    def test_get_git_commit_from_child_directory(self):
+        child_directory = create_directory(self.repo_path / "child_directory")
+        assert get_git_commit(directory=child_directory).endswith(self._local_changes_present)
